@@ -14,11 +14,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <stdio.h>
 #include <string.h>
 
 #include "xklavier_private.h"
+#include "xklavier_private_xkb.h"
 
+#ifdef XKB_HEADERS_PRESENT
 static void _XkbModsRecDump( FILE * fs, XkbModsRec * mods )
 {
   fprintf( fs, "flags: 0x%X\n", mods->mask );
@@ -262,6 +263,7 @@ void _XkbDescDump( FILE * fs, int level, XkbDescPtr kbd )
     _XkbClientMapDump( fs, level + 2, kbd->map, kbd );
   } else
     fprintf( fs, "%*sNO map\n", level, "" );
+  fprintf( fs, "XKB libraries not present\n" );
 }
 
 void XklDumpXkbDesc( const char *filename, XkbDescPtr kbd )
@@ -274,3 +276,4 @@ void XklDumpXkbDesc( const char *filename, XkbDescPtr kbd )
   }
 
 }
+#endif
